#!/usr/bin/python3
# Built with Python 3.9.7
#
# Start Date:
# 23/09/2021
#
# Hub Port Assignemnts
#   LUX1000_0 (LSPort) -> Port 2
#   PSU2000_0 (PMPort) -> Port 1
#   HUM1100_0 (MSPort) -> Port 0

from Phidget22.Devices.DigitalOutput import *
from Phidget22.Devices.VoltageRatioInput import *
from Phidget22.Devices.LightSensor import *
import time

class main:
    
    # Constructor 
    def __init__(self): 
        # Assign Phidgets to inner class
        self.LightSensor = LightSensor()
        self.MoistureSensor = VoltageRatioInput()
        self.Pump = DigitalOutput()
        
        # These Assignments are for port decleration, you may wish to change these
        self.LSPort = 2
        self.MSPort = 0
        self.PMPort = 1
        
        # This value is the threshold at which the pump will be enabled/disabled
        # When the measured voltage is less than this value pump will turn on
        self.VoltageThreshold = 0.4

    def OpenObjects(self):
        #Add local Variables
        LightSensor = self.LightSensor
        MoistureSensor = self.MoistureSensor
        Pump = self.Pump

        # Assign Hub Ports
        LightSensor.setHubPort(self.LSPort)
        MoistureSensor.setHubPort(self.MSPort)
        Pump.setHubPort(self.PMPort)

        # Open Objects
        LightSensor.setIsHubPortDevice(False)
        MoistureSensor.setIsHubPortDevice(False)
        Pump.setIsHubPortDevice(True)

        LightSensor.openWaitForAttachment(1000)
        MoistureSensor.openWaitForAttachment(1000)
        Pump.openWaitForAttachment(1000)

    def Run(self):
        #Add local Variables
        LightSensor = self.LightSensor
        MoistureSensor = self.MoistureSensor
        Pump = self.Pump
        VoltageThreshold = self.VoltageThreshold

        # Main loop. All Major events are here
        while (True):

            # Measure soil moisture. 
            if (MoistureSensor.getVoltageRatio() < VoltageThreshold):
                
                # Enable Pump, wait three seconds, then shut it off and measure again
                print("Watering Plant.")
                Pump.setState(1)
                time.sleep(3)
                Pump.setState(0)
            
            # Output light value
            print ("Light Measurement (Lux): {}".format(LightSensor.getIlluminance()))
            time.sleep(0.1)

    def ClosePhidgets(self):
        # This will be called in the event of a keyboard interrupt
        # It will close all Phidgets properly 
        self.LightSensor.close()
        self.MoistureSensor.close()
        self.Pump.close()

# Run Program
handler = main()
try:
    handler.OpenObjects()
    handler.Run()

# Catch CTRL + C interrupt and close
except KeyboardInterrupt:
    print("KeyboardInterrupt, Quitting!")
    handler.ClosePhidgets()

        
        

